Examples
========
In this section, we provide a catalog of example Jupyter notebooks that
demonstrate the various functionalities offered by `XRTpy`. These notebooks
serve as practical guides for utilizing the features and capabilities of XRTpy
in different scenarios. By exploring these examples, users can gain a better
understanding of how to effectively use XRTpy for their analysis tasks.

.. contents::
   :local:

Getting started
---------------

.. nbgallery::
  :glob:

  notebooks/getting_started/*

Computing response functions
----------------------------

.. nbgallery::
  :glob:

  notebooks/computing_functions/*

Data analysis
-------------

.. nbgallery::
   :glob:

   notebooks/data_analysis/*
